<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:zw="java:cz.euweb.icebearsoft.saxon.ExtUtils"
                xmlns:saxon="http://saxon.sf.net/"
                version="2.0"
                saxon:trace="no"
                exclude-result-prefixes="zw xs"
                extension-element-prefixes="saxon">
   <xsl:template match="zw" mode="#all">
      <xsl:choose>
         <xsl:when test="not(@lang) and not(@notlang)"/>
         <xsl:when test="contains(@notlang, $DocumentLanguage)">
            <xsl:apply-templates select="zw" mode="#current"/>
         </xsl:when>
         <xsl:when test="contains(@lang, $DocumentLanguage) or not(@lang)">
            <xsl:apply-templates mode="#current"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:apply-templates select="zw" mode="#current"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>
   <xsl:output method="html" indent="yes" encoding="utf-8"/>
   <xsl:param name="DocumentLanguage"/>
   <xsl:strip-space elements="*"/>
   <xsl:preserve-space elements="xsl:text p i b li dt dd zw pre"/>
   <xsl:variable name="basename">
      <xsl:analyze-string select="saxon:systemId()" regex="[^/]+\.xml$">
         <xsl:matching-substring>
            <xsl:value-of select="."/>
         </xsl:matching-substring>
      </xsl:analyze-string>
   </xsl:variable>
   <xsl:variable name="backdir">
      <xsl:analyze-string select="substring-after(saxon:systemId(), &#34;/xml/&#34;)" regex="[^/]+/">
         <xsl:matching-substring>
            <xsl:text>../</xsl:text>
         </xsl:matching-substring>
      </xsl:analyze-string>
   </xsl:variable>
   <xsl:variable name="home">
      <xsl:choose>
         <xsl:when test="$backdir = ''">
            <xsl:text>./</xsl:text>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="$backdir"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:variable>
   <xsl:variable name="mainpage">
      <xsl:choose>
         <xsl:when test="$DocumentLanguage = 'cs'">
            <xsl:text>Hlavní stránka</xsl:text>
         </xsl:when>
         <xsl:when test="$DocumentLanguage = 'hi'">
            <xsl:text>मुख्य पृष्ठ</xsl:text>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>Main page</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:variable>
   <xsl:variable name="htmlext">
      <xsl:text>.php</xsl:text>
   </xsl:variable>
   <xsl:template match="/">
      <xsl:processing-instruction name="php">
if (!function_exists('FindLanguage')) {
require 'functions.php';
EmitHeader(basename($_SERVER['SCRIPT_NAME']));
}
Expires();
?</xsl:processing-instruction>
      <html>
         <xsl:apply-templates select="document"/>
      </html>
   </xsl:template>
   <xsl:template match="zw-online">
      <xsl:apply-templates/>
   </xsl:template>
   <xsl:template match="zw-offline"/>
   <xsl:variable name="ignore-role">offline</xsl:variable>
   <xsl:template match="zw-datetime" name="zw-datetime">
      <xsl:choose use-when="function-available(&#34;zw:last-modified&#34;)">
         <xsl:when test="@file">
            <xsl:value-of select="zw:file-timestamp(@file)"/>
         </xsl:when>
         <xsl:when test="@xmlfile">
            <xsl:value-of select="zw:last-modified(document(@xmlfile))"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="zw:last-modified()"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>
   <xsl:template match="zw-date">
      <xsl:variable name="datetime">
         <xsl:call-template name="zw-datetime"/>
      </xsl:variable>
      <xsl:value-of select="substring-before($datetime, &#34;T&#34;)"/>
   </xsl:template>
   <xsl:template match="document">
      <head>
         <meta name="google-site-verification"
               content="pQX0Li9frYMCGMBkoPTHoG3lgeK_Gx9i-BO8-jcjn18"/>
         <meta name="viewport" content="width=device-width, initial-scale=1"/>
         <meta name="http-equiv" content="{concat('Content-Language: ', $DocumentLanguage)}"/>
         <xsl:call-template name="doc-title"/>
         <xsl:if test="@css">
            <xsl:call-template name="doc-css"/>
         </xsl:if>
         <xsl:if test="@redirect">
            <meta http-equiv="refresh" content="{concat('1; ', @redirect)}"/>
         </xsl:if>
         <script>
  (function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
  (i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
  m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
  })(window,document,'script','https://www.google-analytics.com/analytics.js','ga');

  ga('create', 'UA-98691706-1', 'auto');
  ga('send', 'pageview');

            </script>
      </head>
      <xsl:call-template name="doc-body"/>
   </xsl:template>
   <xsl:template name="doc-title">
      <title>
         <xsl:choose>
            <xsl:when test="count(titlebar)&gt;0">
               <xsl:apply-templates select="titlebar" mode="titlebar"/>
            </xsl:when>
            <xsl:otherwise>
               <xsl:apply-templates select="title" mode="titlebar"/>
            </xsl:otherwise>
         </xsl:choose>
      </title>
      <xsl:apply-templates select="head" mode="title"/>
   </xsl:template>
   <xsl:template name="doc-body">
      <body>
         <xsl:copy-of select="@* except (@top|@css)"/>
         <h1 id="top">
            <xsl:apply-templates select="title" mode="title"/>
         </h1>
         <xsl:apply-templates>
            <xsl:with-param name="hdr" select="2"/>
         </xsl:apply-templates>
         <xsl:if test="@top &gt; 0">
            <xsl:call-template name="top-link"/>
         </xsl:if>
         <xsl:call-template name="footer"/>
      </body>
   </xsl:template>
   <xsl:template name="footer">
      <br/>
      <br/>
      <br/>
      <xsl:variable name="urlbase" select="concat($backdir, $basename)"/>
      <xsl:choose>
         <xsl:when test="$urlbase = 'index.xml'">
            <hr/>
         </xsl:when>
         <xsl:otherwise>
            <div class="links">
               <xsl:call-template name="other-links"/>
               <xsl:if test="starts-with($urlbase, '../') and $basename != 'index.xml'">
                  <a href="./">
                     <xsl:attribute name="title">
                        <xsl:choose>
                           <xsl:when test="count(document('index.xml', /)/document/titlebar) &gt; 0">
                              <xsl:apply-templates select="document(&#34;index.xml&#34;, /)/document/titlebar" mode="titlebar"/>
                           </xsl:when>
                           <xsl:otherwise>
                              <xsl:apply-templates select="document(&#34;index.xml&#34;, /)/document/title" mode="titlebar"/>
                           </xsl:otherwise>
                        </xsl:choose>
                     </xsl:attribute>
                     <xsl:apply-templates select="document(&#34;index.xml&#34;, /)/document/title" mode="titlebar"/>
                  </a>
                  <br/>
               </xsl:if>
               <a title="{$mainpage}" href="{$home}">
                  <xsl:value-of select="$mainpage"/>
               </a>
            </div>
         </xsl:otherwise>
      </xsl:choose>
      <div id="copyright">
         <xsl:text>&#169; Z. Wagner - Ice Bear Soft, </xsl:text>
         <xsl:value-of select="zw:last-modified()" use-when="function-available(&#34;zw:last-modified&#34;)"/>
      </div>
      <xsl:text>
</xsl:text>
      <xsl:processing-instruction name="php"> LangLinks(); Counter(); ?</xsl:processing-instruction>
      <xsl:comment>WZ-REKLAMA-1.0</xsl:comment>
      <xsl:if test="@reklama">
         <hr/>
         <xsl:apply-templates select="document(@reklama)" mode="include"/>
      </xsl:if>
   </xsl:template>
   <xsl:template name="other-links">
      <xsl:apply-templates select="//zw-a" mode="footer"/>
   </xsl:template>
   <xsl:template match="zw-a" mode="footer">
      <xsl:choose>
         <xsl:when test="@notlang eq $DocumentLanguage"/>
         <xsl:when test="@lang ne '' and @lang ne $DocumentLanguage"/>
         <xsl:otherwise>
            <xsl:call-template name="zw-a"/>
            <br/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>
   <xsl:template name="zw-a">
      <a>
         <xsl:copy-of select="@*"/>
         <xsl:call-template name="zw-a-content"/>
      </a>
   </xsl:template>
   <xsl:template match="zw-a"/>
   <xsl:template name="zw-a-content">
      <xsl:choose>
         <xsl:when test="count(*) &gt; 0 or string-length(.) &gt; 0">
            <xsl:if test="title">
               <xsl:attribute name="title">
                  <xsl:apply-templates select="title" mode="titlebar"/>
               </xsl:attribute>
            </xsl:if>
            <xsl:apply-templates select="*|text() except title"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:choose>
               <xsl:when test="contains(@href, &#34;#&#34;)">
                  <xsl:variable name="xml" as="xs:string"
                                select="if (starts-with(@href, &#34;#&#34;)) then @href else replace(replace(@href, &#34;/#&#34;, &#34;/index.php#&#34;), &#34;\.php#&#34;, &#34;.xml#&#34;)"/>
                  <xsl:variable name="root"
                                select="if (starts-with(@href, &#34;#&#34;)) then (/) else document(substring-before($xml, &#34;#&#34;), /)"/>
                  <xsl:variable name="title" as="element()"
                                select="$root//section[@label=substring-after($xml,&#34;#&#34;)]/title"/>
                  <xsl:attribute name="title">
                     <xsl:apply-templates select="$title" mode="titlebar"/>
                  </xsl:attribute>
                  <xsl:apply-templates select="$title" mode="title"/>
               </xsl:when>
               <xsl:otherwise>
                  <xsl:variable name="xml" as="xs:string"
                                select="replace(replace(@href, &#34;/$&#34;, &#34;/index.php&#34;), &#34;\.php$&#34;, &#34;.xml&#34;)"/>
                  <xsl:attribute name="title">
                     <xsl:choose>
                        <xsl:when test="count(document($xml, /)/document/titlebar) &gt; 0">
                           <xsl:apply-templates select="document($xml, /)/document/titlebar" mode="titlebar"/>
                        </xsl:when>
                        <xsl:otherwise>
                           <xsl:apply-templates select="document($xml, /)/document/title" mode="titlebar"/>
                        </xsl:otherwise>
                     </xsl:choose>
                  </xsl:attribute>
                  <xsl:apply-templates select="document($xml, /)/document/title" mode="nologo"/>
               </xsl:otherwise>
            </xsl:choose>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>
   <xsl:template match="title|titlebar|head" mode="title titlebar nologo">
      <xsl:apply-templates mode="#current"/>
   </xsl:template>
   <xsl:template match="title|titlebar|head"/>
   <xsl:template name="doc-css">
      <xsl:for-each select="tokenize(@css, '\s+')">
         <xsl:variable name="css">
            <xsl:choose>
               <xsl:when test=".='.'">
                  <xsl:value-of select="$backdir"/>
                  <xsl:text>css/style.css</xsl:text>
               </xsl:when>
               <xsl:otherwise>
                  <xsl:value-of select="."/>
               </xsl:otherwise>
            </xsl:choose>
         </xsl:variable>
         <link rel="stylesheet" href="{$css}" type="text/css"/>
      </xsl:for-each>
      <xsl:variable name="favicon" select="concat($backdir, 'images/favicon.ico')"/>
      <link rel="shortcut icon" type="image/x-icon" href="{$favicon}"/>
   </xsl:template>
   <xsl:template name="secnum">
      <xsl:number level="multiple" format="1."
                  count="section[not(@role) or @role != $ignore-role]"/>
   </xsl:template>
   <xsl:template name="seclabel">
      <xsl:choose>
         <xsl:when test="@label">
            <xsl:value-of select="@label"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="generate-id()"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>
   <xsl:template match="section">
      <xsl:param name="hdr"/>
      <xsl:if test="not(@role) or @role != $ignore-role">
         <xsl:variable name="label">
            <xsl:call-template name="seclabel"/>
         </xsl:variable>
         <xsl:element name="{concat('h', string($hdr))}">
            <xsl:attribute name="id" select="$label"/>
            <xsl:call-template name="secnum"/>
            <xsl:text> </xsl:text>
            <xsl:apply-templates select="title" mode="title"/>
         </xsl:element>
         <xsl:apply-templates>
            <xsl:with-param name="hdr" select="$hdr + 1"/>
         </xsl:apply-templates>
         <xsl:if test="/document/@top&gt;=$hdr and count(following-sibling::element()[name()!='zw-a'] except following-sibling::section[@role=$ignore-role]/descendant-or-self::element())&gt;0">
            <xsl:call-template name="top-link"/>
         </xsl:if>
      </xsl:if>
   </xsl:template>
   <xsl:template match="a" mode="title">
      <xsl:call-template name="zw-a"/>
   </xsl:template>
   <xsl:template name="top-link">
      <xsl:variable name="top">
         <xsl:text>&#160;</xsl:text>
         <xsl:call-template name="top"/>
         <xsl:text>&#160;</xsl:text>
      </xsl:variable>
      <div>
         <table class="top" align="right" border="1" frame="box" rules="none">
            <tr>
               <td>
                  <a href="#top" title="{$top}">
                     <xsl:value-of select="$top"/>
                  </a>
               </td>
            </tr>
         </table>
      </div>
   </xsl:template>
   <xsl:template name="top">
      <xsl:choose>
         <xsl:when test="$DocumentLanguage='cs'">
            <xsl:text>Začátek&#160;stránky</xsl:text>
         </xsl:when>
         <xsl:when test="$DocumentLanguage='en'">
            <xsl:text>Top&#160;of&#160;the&#160;page</xsl:text>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>Top&#160;of&#160;the&#160;page</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>
   <xsl:template name="toc-heading" match="toc-heading">
      <p>
         <b>
            <xsl:choose>
               <xsl:when test="$DocumentLanguage='cs'">
                  <xsl:text>Obsah</xsl:text>
               </xsl:when>
               <xsl:when test="$DocumentLanguage='en'">
                  <xsl:text>Contents</xsl:text>
               </xsl:when>
               <xsl:when test="$DocumentLanguage='hi'">
                  <xsl:text>विषय-सूची</xsl:text>
               </xsl:when>
               <xsl:otherwise>
                  <xsl:text>Contents</xsl:text>
               </xsl:otherwise>
            </xsl:choose>
         </b>
      </p>
   </xsl:template>
   <xsl:template match="toc">
      <xsl:variable name="depth">
         <xsl:value-of select="max(for $s in ((..//section[not(section)]|/) except (//element()[role=$ignore-role]/descendant-or-self::element())) return count($s/ancestor::element())) - count(../ancestor::element())"/>
      </xsl:variable>
      <xsl:if test="$depth &gt; 0">
         <xsl:choose>
            <xsl:when test="count(*) &gt; 0">
               <xsl:apply-templates/>
            </xsl:when>
            <xsl:when test="@heading='yes'">
               <xsl:call-template name="toc-heading"/>
            </xsl:when>
         </xsl:choose>
         <table border="0" frame="none" rules="none" class="toc">
            <xsl:apply-templates select="../section" mode="toc">
               <xsl:with-param name="span" select="$depth"/>
            </xsl:apply-templates>
         </table>
      </xsl:if>
   </xsl:template>
   <xsl:template match="section" mode="toc">
      <xsl:param name="indent" select="0"/>
      <xsl:param name="span" select="-1"/>
      <xsl:if test="not(@role) or @role != $ignore-role">
         <xsl:variable name="label">
            <xsl:call-template name="seclabel"/>
         </xsl:variable>
         <tr>
            <xsl:if test="$indent &gt; 0">
               <td>
                  <xsl:if test="$indent &gt; 1">
                     <xsl:attribute name="colspan">
                        <xsl:value-of select="$indent"/>
                     </xsl:attribute>
                  </xsl:if>
                  <xsl:text>&#160;</xsl:text>
               </td>
            </xsl:if>
            <td align="right">
               <a href="{concat('#', $label)}">
                  <xsl:call-template name="secnum"/>
               </a>
            </td>
            <td>
               <xsl:if test="$span &gt; 1">
                  <xsl:attribute name="colspan">
                     <xsl:value-of select="$span"/>
                  </xsl:attribute>
               </xsl:if>
               <a href="{concat('#', $label)}">
                  <xsl:apply-templates select="title" mode="toc"/>
               </a>
            </td>
         </tr>
         <xsl:apply-templates select="section" mode="toc">
            <xsl:with-param name="indent" select="$indent + 1"/>
            <xsl:with-param name="span" select="$span - 1"/>
         </xsl:apply-templates>
      </xsl:if>
   </xsl:template>
   <xsl:template match="a" mode="toc">
      <xsl:call-template name="zw-a-content"/>
   </xsl:template>
   <xsl:template match="zw-logo" mode="#default title">
      <a title="{$mainpage}" href="{$home}">
         <img src="{concat($backdir, 'images/ibslogo1.gif')}" width="175" height="45"
              alt="Ice Bear Soft"
              align="right"
              border="0"/>
      </a>
   </xsl:template>
   <xsl:template match="zw-logo" mode="titlebar nologo"/>
   <xsl:template match="a|zw-label">
      <xsl:call-template name="zw-a"/>
   </xsl:template>
   <xsl:template match="zw-jsimg">
      <xsl:processing-instruction name="php">
         <xsl:text>jsimg('</xsl:text>
         <xsl:value-of select="@src"/>
         <xsl:text>', '</xsl:text>
         <xsl:value-of select="@align"/>
         <xsl:text>');</xsl:text> ?</xsl:processing-instruction>
   </xsl:template>
   <xsl:template match="zw-comment">
      <xsl:comment>
         <xsl:apply-templates/>
      </xsl:comment>
   </xsl:template>
   <xsl:template match="zw-hide">
      <span class="hide">
         <xsl:value-of select="@alt"/>
      </span>
   </xsl:template>
   <xsl:template match="zw-info">
      <xsl:if test="@include = &#34;yes&#34;">
         <xsl:apply-templates/>
      </xsl:if>
   </xsl:template>
   <xsl:template match="processing-instruction(&#34;php&#34;)">
      <xsl:processing-instruction name="php">
         <xsl:value-of select="."/>
         <xsl:text>?</xsl:text>
      </xsl:processing-instruction>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="#all"/>
   <xsl:template match="*" mode="#default title nologo">
      <xsl:element name="{name()}">
         <xsl:apply-templates select="@*"/>
         <xsl:apply-templates mode="#current"/>
      </xsl:element>
   </xsl:template>
   <xsl:template match="@*">
      <xsl:copy-of select="."/>
   </xsl:template>
   <xsl:template match="/" mode="include">
      <xsl:apply-templates/>
   </xsl:template>
   <xsl:template match="zw-nopatents" mode="#default title">
      <xsl:variable name="title">
         <xsl:choose>
            <xsl:when test="$DocumentLanguage = &#34;cs&#34;">
               <xsl:text>Žádné softwarové patenty!</xsl:text>
            </xsl:when>
            <xsl:otherwise>
               <xsl:text>No software patents!</xsl:text>
            </xsl:otherwise>
         </xsl:choose>
      </xsl:variable>
      <a href="http://noepatents.eu.org" title="{$title}">
         <img width="480" height="60" src="{concat($backdir, 'images/swpatbanner.en.png')}">
            <xsl:copy-of select="@*"/>
         </img>
      </a>
   </xsl:template>
   <xsl:template match="zw-elem" mode="#default title toc nologo">
      <xsl:call-template name="zw-elem">
         <xsl:with-param name="prefix">
            <xsl:value-of select="@q"/>
         </xsl:with-param>
      </xsl:call-template>
   </xsl:template>
   <xsl:template match="zw-xelem" mode="#default title toc nologo">
      <xsl:call-template name="zw-elem">
         <xsl:with-param name="prefix">
            <xsl:value-of select="@q"/>
            <xsl:text>xsl:</xsl:text>
         </xsl:with-param>
      </xsl:call-template>
   </xsl:template>
   <xsl:template name="zw-elem">
      <xsl:param name="prefix"/>
      <code>
         <xsl:text>&lt;</xsl:text>
         <xsl:value-of select="$prefix"/>
         <xsl:apply-templates/>
         <xsl:text>&gt;</xsl:text>
      </code>
   </xsl:template>
   <xsl:template match="zw-pre|verbatim" name="verbatim">
      <xsl:text>&#10;</xsl:text>
      <table border="2" frame="box" rules="rows" cellpadding="5" class="pre">
         <xsl:if test="@mode">
            <tr>
               <th>
                  <xsl:choose>
                     <xsl:when test="@mode=&#34;old&#34;">
                        <xsl:choose>
                           <xsl:when test="$DocumentLanguage='cs'">
                              <xsl:text>Zastaralý kód</xsl:text>
                           </xsl:when>
                           <xsl:when test="$DocumentLanguage='en'">
                              <xsl:text>Obsolete code</xsl:text>
                           </xsl:when>
                           <xsl:otherwise>
                              <xsl:text>Obsolete code</xsl:text>
                           </xsl:otherwise>
                        </xsl:choose>
                     </xsl:when>
                     <xsl:otherwise>
                        <xsl:text>mode = </xsl:text>
                        <xsl:value-of select="@mode"/>
                     </xsl:otherwise>
                  </xsl:choose>
               </th>
            </tr>
         </xsl:if>
         <tr>
            <td>
               <pre>
                  <xsl:if test="name() != 'verbatim'">
                     <xsl:text>&#10;</xsl:text>
                  </xsl:if>
                  <xsl:apply-templates mode="verbatim"/>
               </pre>
            </td>
         </tr>
      </table>
      <xsl:text>&#10;</xsl:text>
   </xsl:template>
   <xsl:template match="*" mode="verbatim">
      <xsl:param name="indent"/>
      <xsl:param name="amount">
         <xsl:text>  </xsl:text>
      </xsl:param>
      <xsl:param name="endline">
         <xsl:text>&#10;</xsl:text>
      </xsl:param>
      <xsl:value-of select="$indent"/>
      <xsl:text>&lt;</xsl:text>
      <xsl:value-of select="name()"/>
      <xsl:apply-templates select="@*" mode="verbatim"/>
      <xsl:choose>
         <xsl:when test="count(*)=0 and string-length(.)=0">
            <xsl:text>/&gt;</xsl:text>
            <xsl:value-of select="$endline"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>&gt;&#10;</xsl:text>
            <xsl:apply-templates mode="verbatim">
               <xsl:with-param name="indent">
                  <xsl:value-of select="concat($indent, $amount)"/>
               </xsl:with-param>
            </xsl:apply-templates>
            <xsl:value-of select="$indent"/>
            <xsl:text>&lt;/</xsl:text>
            <xsl:value-of select="name()"/>
            <xsl:text>&gt;</xsl:text>
            <xsl:value-of select="$endline"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>
   <xsl:template match="pre">
      <table border="2" frame="box" rules="rows" cellpadding="5" class="pre">
         <tr>
            <td>
               <pre>
                  <xsl:apply-templates/>
               </pre>
            </td>
         </tr>
      </table>
   </xsl:template>
   <xsl:template match="xsl:text|zw-text|xsl:comment|xsl:processing-instruction" mode="verbatim">
      <xsl:param name="indent"/>
      <xsl:value-of select="$indent"/>
      <xsl:text>&lt;</xsl:text>
      <xsl:value-of select="name()"/>
      <xsl:apply-templates select="@*" mode="verbatim"/>
      <xsl:text>&gt;</xsl:text>
      <xsl:choose>
         <xsl:when test="count(*)=0">
            <xsl:value-of select="."/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:apply-templates mode="verbatim">
               <xsl:with-param name="endline"/>
            </xsl:apply-templates>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:text>&lt;/</xsl:text>
      <xsl:value-of select="name()"/>
      <xsl:text>&gt;&#10;</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="verbatim">
      <xsl:text> </xsl:text>
      <xsl:value-of select="name()"/>
      <xsl:text>="</xsl:text>
      <xsl:value-of select="normalize-space(.)"/>
      <xsl:text>"</xsl:text>
   </xsl:template>
   <xsl:template match="text()" mode="verbatim">
      <xsl:value-of select="normalize-space(.)"/>
   </xsl:template>
   <xsl:template match="xsl:stylesheet">
      <xsl:call-template name="verbatim"/>
   </xsl:template>
   <xsl:template match="text()">
      <xsl:variable name="lang" as="node()*"
                    select="(ancestor-or-self::*/@xml:lang |             ancestor-or-self::*/@lang)[last()]"/>
      <xsl:choose>
         <xsl:when test="$lang = 'cs'">
            <xsl:value-of select="replace(., '([ &#xA;(,][AaIiKkOoSsUuVvZz])[ &#xD;&#xA;]+', '$1 ')"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="."/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>
   <xsl:template match="zw-pre/text()|pre/text()|code/text()|verbatim/text()">
      <xsl:value-of select="."/>
   </xsl:template>
</xsl:stylesheet>